"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const docker_command_1 = tslib_1.__importDefault(require("../../docker-command"));
const docker_1 = require("../../utils/docker");
class Logs extends docker_command_1.default {
    async run() {
        const { flags } = this.parse(Logs);
        const services = await this.listServices({
            name: flags.name
        });
        if (services.length === 0)
            return;
        const service = services[0];
        const logs = await service.logs({
            stderr: true,
            stdout: true,
            follow: flags.follow,
            tail: flags.tail && flags.tail >= 0 ? flags.tail : 'all'
        });
        logs.on('data', (buffer) => docker_1.parseLog(buffer).forEach(x => this.log(x)));
        logs.on('error', (error) => {
            throw error;
        });
        return logs;
    }
}
Logs.description = 'Show the Engine\'s logs';
Logs.flags = Object.assign({}, docker_command_1.default.flags, { tail: command_1.flags.integer({
        description: 'Display the last N lines',
        default: -1
    }), follow: command_1.flags.boolean({
        description: 'Follow logs',
        allowNo: true,
        default: true
    }) });
exports.default = Logs;
