"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const docker_command_1 = tslib_1.__importDefault(require("../../docker-command"));
const status_1 = tslib_1.__importDefault(require("./status"));
class Stop extends docker_command_1.default {
    async run() {
        const { flags } = this.parse(Stop);
        const status = await status_1.default.run(['--name', flags.name, '--silent']);
        if (status === 1 /* STOPPED */) {
            this.log('Engine is already stopped');
            return false;
        }
        this.spinner.start('Stopping Engine');
        const services = await this.listServices({ name: flags.name });
        if (services.length === 0)
            return false;
        const service = services[0];
        const eventPromise = this.waitForEvent(({ Action, from, Type }) => Type === 'container' &&
            Action === 'destroy' &&
            from === service.data.Spec.TaskTemplate.ContainerSpec.Image);
        await service.remove();
        await eventPromise;
        this.spinner.stop();
        return true;
    }
}
Stop.description = 'Stop the Engine';
Stop.flags = Object.assign({}, docker_command_1.default.flags);
exports.default = Stop;
