"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const marketplace_command_1 = tslib_1.__importDefault(require("../../marketplace-command"));
class MarketplacePurchase extends marketplace_command_1.default {
    async run() {
        const { args } = this.parse(MarketplacePurchase);
        const account = await this.getAccount();
        this.spinner.start('Verifying offer');
        const preparePurchase = await this.execute({
            instanceHash: await this.engineServiceInstance(marketplace_command_1.default.SERVICE_NAME),
            taskKey: 'preparePurchase',
            inputs: {
                sid: args.SID,
                offerIndex: args.OFFER_ID,
                from: account,
            }
        });
        this.spinner.stop();
        const passphrase = await this.getPassphrase();
        this.spinner.start('Purchasing offer');
        const signedTxs = [];
        for (const tx of preparePurchase.transactions) {
            signedTxs.push(await this.sign(account, tx, passphrase));
        }
        const purchase = await this.execute({
            instanceHash: await this.engineServiceInstance(marketplace_command_1.default.SERVICE_NAME),
            taskKey: 'publishPurchase',
            inputs: {
                signedTransactions: signedTxs.map(x => x.signedTransaction)
            }
        });
        this.spinner.stop();
        this.styledJSON(purchase);
        return purchase;
    }
}
MarketplacePurchase.description = 'Purchase a service';
MarketplacePurchase.flags = Object.assign({}, marketplace_command_1.default.flags);
MarketplacePurchase.args = [{
        name: 'SID',
        description: 'ID of the service',
        required: true,
    }, {
        name: 'OFFER_ID',
        description: 'ID of the offer',
        required: true,
    }];
exports.default = MarketplacePurchase;
