"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const base58 = tslib_1.__importStar(require("mesg-js/lib/util/base58"));
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const error_1 = require("../../utils/error");
const compile_1 = tslib_1.__importDefault(require("./compile"));
const create_1 = tslib_1.__importDefault(require("./create"));
const delete_1 = tslib_1.__importDefault(require("./delete"));
const logs_1 = tslib_1.__importDefault(require("./logs"));
const start_1 = tslib_1.__importDefault(require("./start"));
const stop_1 = tslib_1.__importDefault(require("./stop"));
class ServiceDev extends root_command_1.default {
    constructor() {
        super(...arguments);
        this.serviceCreated = false;
        this.instanceCreated = false;
    }
    async run() {
        const { args, flags } = this.parse(ServiceDev);
        const definition = await compile_1.default.run([args.SERVICE, '--silent']);
        const serviceHash = await this.createService(definition);
        const instanceHash = await this.startService(serviceHash, flags.env);
        const stream = await logs_1.default.run([base58.encode(instanceHash)]);
        process.once('SIGINT', async () => {
            stream.destroy();
            if (this.instanceCreated)
                await stop_1.default.run([base58.encode(instanceHash)]);
            if (this.serviceCreated)
                await delete_1.default.run([base58.encode(serviceHash), '--confirm']);
        });
    }
    async createService(definition) {
        try {
            const service = await this.api.service.create(definition);
            if (!service.hash)
                throw new Error('invalid hash');
            this.serviceCreated = true;
            return service.hash;
        }
        catch (e) {
            if (!error_1.IsAlreadyExistsError.match(e))
                throw e;
            this.warn('service already created');
            return new error_1.IsAlreadyExistsError(e).hash;
        }
    }
    async startService(serviceHash, env) {
        try {
            const instance = await this.api.instance.create({
                serviceHash,
                env
            });
            if (!instance.hash)
                throw new Error('invalid hash');
            this.instanceCreated = true;
            return instance.hash;
        }
        catch (e) {
            if (!error_1.IsAlreadyExistsError.match(e))
                throw e;
            this.warn('service already started');
            return new error_1.IsAlreadyExistsError(e).hash;
        }
    }
}
ServiceDev.description = 'Run a service in development mode';
ServiceDev.flags = Object.assign({}, root_command_1.default.flags, create_1.default.flags, start_1.default.flags);
ServiceDev.args = [{
        name: 'SERVICE',
        description: 'Path or url ([https|mesg]://) of a service',
        default: './'
    }];
exports.default = ServiceDev;
