"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const handlebars_1 = require("handlebars");
const js_yaml_1 = require("js-yaml");
const path_1 = require("path");
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
class ServiceDoc extends root_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceDoc);
        const definition = js_yaml_1.safeLoad(fs_1.readFileSync(path_1.join(args.SERVICE, 'mesg.yml')).toString());
        const markdown = this.generateTemplate(definition);
        if (flags.save) {
            this.saveReadme(args.SERVICE, markdown);
        }
        else {
            this.log(markdown);
        }
        return markdown;
    }
    generateTemplate(data) {
        handlebars_1.registerHelper('or', (a, b) => a ? a : b);
        const template = fs_1.readFileSync(path_1.join(__dirname, '..', '..', '..', 'assets', 'doc.md')).toString();
        return handlebars_1.compile(template)(data);
    }
    saveReadme(servicePath, markdown) {
        const defaultReadmeFileName = fs_1.readdirSync(servicePath).find(file => {
            return /^readme(?:.(?:md|txt)+)?$/i.test(file);
        });
        const readmeFileName = defaultReadmeFileName || 'README.md';
        fs_1.writeFileSync(path_1.join(servicePath, readmeFileName), markdown);
    }
}
ServiceDoc.description = 'Generate documentation for service and print it on stdout';
ServiceDoc.flags = Object.assign({}, root_command_1.default.flags, { save: command_1.flags.boolean({ char: 's', description: 'Save to default readme file' }) });
ServiceDoc.args = [{
        name: 'SERVICE',
        description: 'Path of a service',
        default: './'
    }];
exports.default = ServiceDoc;
