"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const base58 = tslib_1.__importStar(require("mesg-js/lib/util/base58"));
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const instance_resolver_1 = tslib_1.__importDefault(require("../../utils/instance-resolver"));
const detail_1 = tslib_1.__importDefault(require("./detail"));
class ServiceExecute extends root_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceExecute);
        const instanceHash = await instance_resolver_1.default(this.api, args.INSTANCE_HASH);
        const instance = await this.api.instance.get({
            hash: instanceHash
        });
        if (!instance.serviceHash) {
            throw new Error('invalid service hash');
        }
        const service = await detail_1.default.run([base58.encode(instance.serviceHash), '--silent']);
        const task = service.tasks.find((x) => x.key === args.TASK);
        if (!task) {
            throw new Error(`The task ${args.TASK} does not exist in service`);
        }
        const inputs = this.convertValue(task.inputs, this.dataFromFlags(flags));
        const result = await this.execute({
            inputs,
            instanceHash,
            tags: ['CLI'],
            taskKey: args.TASK
        });
        this.styledJSON(result);
        return result;
    }
    dataFromFlags(flags) {
        if (flags.json) {
            return JSON.parse(fs_1.readFileSync(flags.json).toString());
        }
        return (flags.data || []).reduce((acc, item) => {
            const [key, value] = item.split('=');
            return Object.assign({}, acc, { [key]: value });
        }, {});
    }
    convertValue(inputs, data) {
        if (!inputs)
            return {};
        return inputs
            .filter((x) => !!data[x.key])
            .reduce((prev, value) => (Object.assign({}, prev, { [value.key]: this.convert(value.type, data[value.key]) })), {});
    }
    convert(type, value) {
        try {
            return {
                Object: (x) => typeof x === 'string' ? JSON.parse(x) : x,
                String: (x) => x,
                Boolean: (x) => ['true', 't', 'TRUE', 'T', '1'].includes(x),
                Number: (x) => parseFloat(x),
                Any: (x) => x,
            }[type](value);
        }
        catch (_a) {
            this.warn(`Cannot parse ${value} in ${type}`);
            return value;
        }
    }
}
ServiceExecute.description = 'Execute a task on a running service';
ServiceExecute.flags = Object.assign({}, root_command_1.default.flags, { json: command_1.flags.string({ char: 'j', description: 'Path to a JSON file containing the task inputs' }), data: command_1.flags.string({
        char: 'd',
        description: 'Task inputs',
        multiple: true,
        helpValue: 'key=value'
    }) });
ServiceExecute.args = [{
        name: 'INSTANCE_HASH',
        required: true,
    }, {
        name: 'TASK',
        required: true,
        description: 'Task key'
    }];
exports.default = ServiceExecute;
