"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const axios_1 = tslib_1.__importDefault(require("axios"));
const fs_1 = require("fs");
const inquirer_1 = require("inquirer");
const path_1 = require("path");
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const deployer_1 = tslib_1.__importDefault(require("../../utils/deployer"));
const templatesURL = 'https://raw.githubusercontent.com/mesg-foundation/awesome/master/templates.json';
class ServiceInit extends root_command_1.default {
    async run() {
        const { args, flags } = this.parse(ServiceInit);
        const templateUrl = await this.getTemplateUrl(flags.template);
        this.spinner.start('Initialize your project');
        await this.downloadTemplate(args.DIR, templateUrl);
        this.spinner.stop(args.DIR);
        return args.DIR;
    }
    async getTemplateUrl(template) {
        if (template) {
            return template;
        }
        this.spinner.start('Fetching templates');
        const templates = await this.fetchTemplates();
        this.spinner.stop();
        const { value } = (await inquirer_1.prompt({
            type: 'list',
            name: 'value',
            message: 'Select the template to use',
            default: 'Basic',
            choices: templates.map(x => ({
                name: `${x.name} ➜ ${x.url}`,
                value: x.name,
                short: x.name
            }))
        }));
        const selectedTemplate = templates.find(x => x.name === value);
        if (!selectedTemplate) {
            throw new Error(`The template name "${value}" is not valid`);
        }
        return selectedTemplate.url;
    }
    async fetchTemplates() {
        const response = await axios_1.default.get(templatesURL);
        return response.data;
    }
    async downloadTemplate(path, url) {
        const tmpPath = await deployer_1.default(url);
        fs_1.renameSync(path_1.join(tmpPath, 'template'), path);
    }
}
ServiceInit.description = 'Initialize a service from a template';
ServiceInit.flags = Object.assign({}, root_command_1.default.flags, { template: command_1.flags.string({ char: 't', description: 'Specify the template URL to use' }) });
ServiceInit.args = [{
        name: 'DIR',
        required: true,
        description: 'Directory to initialize a service into'
    }];
exports.default = ServiceInit;
