"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const root_command_1 = tslib_1.__importDefault(require("../../root-command"));
const instance_resolver_1 = tslib_1.__importDefault(require("../../utils/instance-resolver"));
class ServiceStop extends root_command_1.default {
    async run() {
        const { argv, flags } = this.parse(ServiceStop);
        if (flags['delete-data'] && !flags.confirm) {
            cli_ux_1.default.warn('This will delete all the data associated with this running service');
            if (!await cli_ux_1.default.confirm('Are you sure?'))
                return [];
        }
        this.spinner.start('Stop running services');
        for (const hash of argv) {
            const instanceHash = await instance_resolver_1.default(this.api, hash);
            await this.api.instance.delete({ hash: instanceHash, deleteData: flags['delete-data'] });
        }
        this.spinner.stop(argv.join(', '));
        return argv;
    }
}
ServiceStop.description = 'Stop one or more running service';
ServiceStop.flags = Object.assign({}, root_command_1.default.flags, { 'delete-data': command_1.flags.boolean({
        description: 'Delete running service persistent data',
        default: false,
    }), confirm: command_1.flags.boolean({
        description: 'Confirm deletion',
        default: false,
    }) });
ServiceStop.strict = false;
ServiceStop.args = [{
        name: 'INSTANCE_HASH...',
        required: true,
    }];
exports.default = ServiceStop;
