"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const fs_1 = require("fs");
const node_docker_api_1 = require("node-docker-api");
const os_1 = require("os");
const path_1 = require("path");
const root_command_1 = tslib_1.__importDefault(require("./root-command"));
class default_1 extends root_command_1.default {
    constructor() {
        super(...arguments);
        this.docker = new node_docker_api_1.Docker(null);
    }
    async listServices(options) {
        return this.docker.service.list({
            filters: { name: [options.name] }
        });
    }
    async waitForEvent(matchFilter) {
        return new Promise(async (resolve) => {
            const events = (await this.docker.events());
            const handler = (buffer) => {
                try {
                    const event = JSON.parse(buffer.toString());
                    if (matchFilter(event)) {
                        events.destroy();
                        return resolve();
                    }
                }
                catch (_a) { }
            };
            events.addListener('data', handler);
        });
    }
    async getOrCreateNetwork(options) {
        const networks = await this.docker.network.list({
            filters: { name: [options.name] }
        });
        if (networks.length > 0) {
            return networks[0];
        }
        return this.docker.network.create({
            CheckDuplicate: true,
            Driver: 'overlay',
            Name: options.name,
            labels: {
                'com.docker.stack.namespace': options.name,
            }
        });
    }
    async createService(network, options) {
        const image = `mesg/engine:${options.version}`;
        const sourcePath = path_1.join(os_1.homedir(), '.mesg');
        if (!fs_1.existsSync(sourcePath)) {
            fs_1.mkdirSync(sourcePath);
        }
        return this.docker.service.create({
            Name: options.name,
            Labels: {
                'com.docker.stack.namespace': options.name,
                'com.docker.stack.image': image,
            },
            TaskTemplate: {
                ContainerSpec: {
                    Image: image,
                    Labels: {
                        'com.docker.stack.namespace': options.name
                    },
                    Env: [
                        `MESG_LOG_FORMAT=${options.format}`,
                        `MESG_LOG_LEVEL=${options.level}`,
                        `MESG_LOG_FORCECOLORS=${options.colors}`,
                        `MESG_NAME=${options.name}`,
                    ],
                    Mounts: [{
                            Source: '/var/run/docker.sock',
                            Target: '/var/run/docker.sock',
                            Type: 'bind',
                        }, {
                            Source: sourcePath,
                            Target: '/root/.mesg',
                            Type: 'bind',
                        }],
                },
                Networks: [
                    {
                        Target: network.id,
                        Alias: options.name,
                    },
                ]
            },
            EndpointSpec: {
                Ports: [{
                        Protocol: 'tcp',
                        PublishMode: 'ingress',
                        TargetPort: 50052,
                        PublishedPort: 50052,
                    }]
            }
        });
    }
}
default_1.flags = Object.assign({}, root_command_1.default.flags, { name: command_1.flags.string({
        description: 'Name of the docker service running the engine',
        required: true,
        default: 'engine'
    }) });
exports.default = default_1;
